@@ -18,8 +18,6 @@
  * DAMAGE.
  */
 
-#include <linux/bits.h>
-#include <linux/string.h>
 #include "jitterentropy-common.h"
 
 #include "jitterentropy-noise.h"
@@ -51,13 +49,13 @@ static __u64 jent_loop_shuffle(struct rand_data *ec,
 	(void)ec;
 	(void)bits;
 
-	return (JCW_BIT_ULL(min));
+	return (BIT_ULL(min));
 
 #else /* JENT_CONF_DISABLE_LOOP_SHUFFLE */
 
 	__u64 time = 0;
 	__u64 shuffle = 0;
-	__u64 mask = (JCW_BIT_ULL(bits)) - 1;
+	__u64 mask = (BIT_ULL(bits)) - 1;
 	unsigned int i = 0;
 
 	/*
@@ -79,7 +77,7 @@ static __u64 jent_loop_shuffle(struct rand_data *ec,
 	 * We add a lower boundary value to ensure we have a minimum
 	 * RNG loop count.
 	 */
-	return (shuffle + (JCW_BIT_ULL(min));
+	return (shuffle + (BIT_ULL(min));
 
 #endif /* JENT_CONF_DISABLE_LOOP_SHUFFLE */
 }
@@ -116,7 +114,7 @@ static void jent_hash_time(struct rand_data *ec, __u64 time,
 	BUILD_BUG_ON((MAX_HASH_LOOP + MIN_HASH_LOOP) > 63);
 
 	/* Use the memset to shut up valgrind */
-	memzero_explicit(intermediary, sizeof(intermediary));
+	jcw_memzero_explicit(intermediary, sizeof(intermediary));
 
 	sha3_256_init(&ctx);
 
@@ -174,8 +172,8 @@ static void jent_hash_time(struct rand_data *ec, __u64 time,
 	if (!stuck)
 		sha3_update(ec->hash_state, (__u8 *)&time, sizeof(__u64));
 
-	memzero_explicit(&ctx, SHA_MAX_CTX_SIZE);
-	memzero_explicit(intermediary, sizeof(intermediary));
+	jcw_memzero_explicit(&ctx, SHA_MAX_CTX_SIZE);
+	jcw_memzero_explicit(intermediary, sizeof(intermediary));
 }
 
 #define MAX_ACC_LOOP_BIT 7
@@ -425,7 +423,7 @@ void jent_read_random_block(struct rand_data *ec, char *dst, size_t dst_len)
 	 * of the old data is not considered to have entropy.
 	 */
 	sha3_update(ec->hash_state, jent_block, sizeof(jent_block));
-	memzero_explicit(jent_block, sizeof(jent_block));
+	jcw_memzero_explicit(jent_block, sizeof(jent_block));
 }
 void jent_hash_time_export(struct rand_data *ec, __u64 time,
                         __u64 loop_cnt, unsigned int stuck)
