@@ -18,8 +18,6 @@
  * DAMAGE.
  */
 
-#include <linux/string.h>
-
 #include "jitterentropy-sha3.h"
 #include "jitterentropy.h"
 
@@ -331,7 +329,7 @@ void sha3_final(struct sha_ctx *ctx, __u8 *digest)
 	/* Final round in sponge absorbing phase */
 
 	/* Fill the unused part of the partial buffer with zeros */
-	memzero_explicit(ctx->partial + partial, ctx->r - partial);
+	jcw_memzero_explicit(ctx->partial + partial, ctx->r - partial);
 
 	/*
 	 * Add the leading and trailing bit as well as the 01 bits for the
@@ -355,7 +353,7 @@ void sha3_final(struct sha_ctx *ctx, __u8 *digest)
 	if (ctx->digestsize % 8)
 		le32_to_ptr(digest, (__u32)(ctx->state[i]));
 
-	memzero_explicit(ctx->partial, ctx->r);
+	jcw_memzero_explicit(ctx->partial, ctx->r);
 	sha3_init(ctx);
 }
 
